"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useIosInitRemoteNotifications = void 0;
var _videoReactBindings = require("@stream-io/video-react-bindings");
var _react = require("react");
var _utils = require("../../utils");
var _ios = require("../../utils/push/ios");
/**
 * This hook is used to initialize the push token for iOS.
 */
const useIosInitRemoteNotifications = () => {
  const client = (0, _videoReactBindings.useStreamVideoClient)();
  const connectedUserId = (0, _videoReactBindings.useConnectedUser)()?.id;
  (0, _react.useEffect)(() => {
    const pushConfig = _utils.StreamVideoRN.getConfig().push;
    // NOTE: we need to wait for user to be connected before we can send the push token
    if (!client || !connectedUserId || !pushConfig) {
      return;
    }
    let unsubscribe = () => {};
    (0, _ios.initIosNonVoipToken)(client, pushConfig, unsubscribeListener => {
      unsubscribe = unsubscribeListener;
    });
    return () => {
      unsubscribe();
    };
  }, [client, connectedUserId]);
};
exports.useIosInitRemoteNotifications = useIosInitRemoteNotifications;
//# sourceMappingURL=useIosInitRemoteNotifications.js.map