"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useProcessPushNonRingingCallEffect = void 0;
var _rxSubjects = require("../../utils/push/internal/rxSubjects");
var _react = require("react");
var _utils = require("../../utils");
var _videoReactBindings = require("@stream-io/video-react-bindings");
var _operators = require("rxjs/operators");
var _utils2 = require("../../utils/push/internal/utils");
var _videoClient = require("@stream-io/video-client");
/**
 * This hook is used to process the non ringing call data via push notifications using the relevant rxjs subject
 * Note: this effect cannot work when push notifications are received when the app is in quit state or in other words when the client is not connected with a websocket.
 * So we essentially run this effect only when the client is connected with a websocket.
 */
const useProcessPushNonRingingCallEffect = () => {
  const client = (0, _videoReactBindings.useStreamVideoClient)();
  const connectedUserId = (0, _videoReactBindings.useConnectedUser)()?.id;
  // The Effect to automatically add the non ringing call to our low level client state
  (0, _react.useEffect)(() => {
    const pushConfig = _utils.StreamVideoRN.getConfig().push;
    if (!pushConfig || !client || !connectedUserId) {
      return;
    }
    const subscription = _rxSubjects.pushNonRingingCallData$.pipe((0, _operators.filter)(NotUndefined)).subscribe(async ({
      cid,
      type
    }) => {
      (0, _videoClient.getLogger)(['useProcessPushNonRingingCallEffect'])('debug', `processNonIncomingCallFromPush with callCId: ${cid} and type: ${type}`);
      await (0, _utils2.processNonIncomingCallFromPush)(client, cid, type);
      _rxSubjects.pushNonRingingCallData$.next(undefined); // remove the current data to avoid processing again
    });
    return () => {
      subscription.unsubscribe();
    };
  }, [client, connectedUserId]);
};

/**
 * A type guard to check if the data is not undefined
 */
exports.useProcessPushNonRingingCallEffect = useProcessPushNonRingingCallEffect;
function NotUndefined(data) {
  return data !== undefined;
}
//# sourceMappingURL=useProcessPushNonRingingCallEffect.js.map