"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DeviceStats = void 0;
var _videoReactBindings = require("@stream-io/video-react-bindings");
var _react = require("react");
var _videoClient = require("@stream-io/video-client");
var _reactNative = require("react-native");
const eventEmitter = _reactNative.NativeModules?.StreamVideoReactNative ? new _reactNative.NativeEventEmitter(_reactNative.NativeModules?.StreamVideoReactNative) : undefined;

/**
 * This is a renderless component to get the device stats like thermal state and power saver mode.
 */
const DeviceStats = () => {
  const {
    useCallCallingState
  } = (0, _videoReactBindings.useCallStateHooks)();
  const callingState = useCallCallingState();
  (0, _react.useEffect)(() => {
    if (callingState !== _videoClient.CallingState.JOINED) {
      return;
    }
    _reactNative.NativeModules?.StreamVideoReactNative.isLowPowerModeEnabled().then(initialPowerMode => (0, _videoClient.setPowerState)(initialPowerMode));
    const powerModeSubscription = eventEmitter?.addListener('isLowPowerModeEnabled', isLowPowerMode => (0, _videoClient.setPowerState)(isLowPowerMode));
    _reactNative.NativeModules?.StreamVideoReactNative.currentThermalState().then(initialState => (0, _videoClient.setThermalState)(initialState));
    const thermalStateSubscription = eventEmitter?.addListener('thermalStateDidChange', thermalState => (0, _videoClient.setThermalState)(thermalState));

    // on android we need to explicitly start and stop the thermal status updates
    if (_reactNative.Platform.OS === 'android') {
      _reactNative.NativeModules?.StreamVideoReactNative.startThermalStatusUpdates();
    }
    return () => {
      powerModeSubscription?.remove();
      thermalStateSubscription?.remove();
      if (_reactNative.Platform.OS === 'android') {
        _reactNative.NativeModules?.StreamVideoReactNative.stopThermalStatusUpdates();
      }
    };
  }, [callingState]);
  return null;
};
exports.DeviceStats = DeviceStats;
//# sourceMappingURL=DeviceStats.js.map