"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDebouncedValue = useDebouncedValue;
var _react = require("react");
/**
 * this is a custom hook that takes a value and a delay and returns a debounced value
 * @param {T} value
 * @param {number} delay
 * @returns {T}
 */
function useDebouncedValue(value, delay) {
  const [debouncedValue, setDebouncedValue] = (0, _react.useState)(value);
  (0, _react.useEffect)(() => {
    const timer = setTimeout(() => setDebouncedValue(value), delay);
    return () => {
      clearTimeout(timer);
    };
  }, [value, delay]);
  return debouncedValue;
}
//# sourceMappingURL=useDebouncedValue.js.map