export let FloatingViewAlignment = /*#__PURE__*/function (FloatingViewAlignment) {
  // Aligns the floating view to the top left corner.
  FloatingViewAlignment[FloatingViewAlignment["topLeft"] = 0] = "topLeft";
  // Aligns the floating view to the top right corner.
  FloatingViewAlignment[FloatingViewAlignment["topRight"] = 1] = "topRight";
  // Aligns the floating view to the bottom left corner.
  FloatingViewAlignment[FloatingViewAlignment["bottomLeft"] = 2] = "bottomLeft";
  // Aligns the floating view to the bottom right corner.
  FloatingViewAlignment[FloatingViewAlignment["bottomRight"] = 3] = "bottomRight";
  return FloatingViewAlignment;
}({});
// find the bounds for the floating view
export function getSnapAlignments({
  rootContainerDimensions,
  floatingViewDimensions
}) {
  const right = rootContainerDimensions.width - floatingViewDimensions.width;
  const bottom = rootContainerDimensions.height - floatingViewDimensions.height;
  const snapOffsets = {
    [FloatingViewAlignment.topLeft]: {
      x: 0,
      y: 0
    },
    [FloatingViewAlignment.topRight]: {
      x: right,
      y: 0
    },
    [FloatingViewAlignment.bottomLeft]: {
      x: 0,
      y: bottom
    },
    [FloatingViewAlignment.bottomRight]: {
      x: right,
      y: bottom
    }
  };
  return snapOffsets;
}

// which is the closest snap alignment to the current position?
// this is done by finding the closest snap offset by computing which point is
// in the minimum distance between the current position and all the 4 snap offset bounds
export function getClosestSnapAlignment({
  position,
  snapAlignments
}) {
  'worklet';

  let minDistanceSquared = Number.MAX_VALUE;
  let closestSnapAlignmentKey = FloatingViewAlignment.topRight;
  for (const key in snapAlignments) {
    // NOTE: key is a string always but we know that it is a FloatingViewAlignment, so we have to cast it unfortunately
    const currentAlignmentKey = key;
    const offset = snapAlignments[currentAlignmentKey];
    const currDistanceSquared = (offset.x - position.x) * (offset.x - position.x) + (offset.y - position.y) * (offset.y - position.y);
    if (currDistanceSquared < minDistanceSquared) {
      minDistanceSquared = currDistanceSquared;
      closestSnapAlignmentKey = currentAlignmentKey;
    }
  }
  return snapAlignments[closestSnapAlignmentKey];
}
export const floatingChildViewContainerStyle = {
  alignSelf: 'flex-start'
};
//# sourceMappingURL=common.js.map