import { useCallback } from 'react';
import { useScreenshotIosContext } from '../contexts/internal/ScreenshotIosContext';
import { NativeModules, Platform } from 'react-native';
import { getLogger } from '@stream-io/video-client';
const {
  StreamVideoReactNative
} = NativeModules;

/**
 * Hook that provides functionality to take screenshots of participant video streams.
 *
 * @returns An object containing the `takeScreenShot` function that captures a participant's video.
 */

export function useScreenshot() {
  const {
    take
  } = useScreenshotIosContext();
  const takeScreenshot = useCallback(async (participant, videoTrackType) => {
    if (Platform.OS === 'android') {
      const {
        videoStream,
        screenShareStream
      } = participant;
      const videoStreamForScreenshot = videoTrackType === 'screenShareTrack' ? screenShareStream : videoStream;
      if (videoStreamForScreenshot) {
        try {
          return await StreamVideoReactNative.takeScreenshot(videoStreamForScreenshot.toURL());
        } catch (error) {
          getLogger(['useScreenshot'])('error', 'Error taking screenshot', error);
          return null;
        }
      }
      return null;
    } else {
      try {
        return await take(participant, videoTrackType);
      } catch (error) {
        getLogger(['useScreenshot'])('error', 'Error taking screenshot', error);
        return null;
      }
    }
  }, [take]);
  return {
    takeScreenshot
  };
}
//# sourceMappingURL=useScreenshot.js.map