import React from 'react';
import { CallControlsButton } from './CallControlsButton';
/**
 * The props for the Hang up call button in the Call Controls.
 */
export type HangUpCallButtonProps = {
    /**
     * Handler to override the hang up handler when the hangup button is pressed.
     * @returns void
     */
    onPressHandler?: () => void;
    /**
     * Handler to be called when the call is hanged up.
     *
     * Note: If the `onPressHandler` is passed this handler will not be executed.
     */
    onHangupCallHandler?: () => void;
    /**
     * Sets the height, width and border-radius (half the value) of the button.
     */
    size?: React.ComponentProps<typeof CallControlsButton>['size'];
};
/**
 * Button to hangup a call.
 *
 * Mostly calls call.leave() internally.
 */
export declare const HangUpCallButton: ({ size, onPressHandler, onHangupCallHandler, }: HangUpCallButtonProps) => React.JSX.Element;
//# sourceMappingURL=HangupCallButton.d.ts.map