import React from 'react';
import { type StreamVideoParticipant } from '@stream-io/video-client';
import { type ParticipantViewComponentProps, type ParticipantViewProps } from '../../Participant/ParticipantView';
import type { CallContentProps } from '../CallContent';
export type CallParticipantsListComponentProps = ParticipantViewComponentProps & {
    /**
     * Component to customize the participant view.
     */
    ParticipantView?: React.ComponentType<ParticipantViewProps> | null;
};
/**
 * Props of the CallParticipantsList component
 */
export type CallParticipantsListProps = CallParticipantsListComponentProps & Pick<CallContentProps, 'supportedReactions'> & {
    /**
     * The list of participants to display in the list
     */
    participants: StreamVideoParticipant[];
    /**
     * The number of columns to display in the list of participants while in vertical or horizontal scrolling mode. This property is only used when there are more than 2 participants.
     * @default 2
     */
    numberOfColumns?: number;
    /**
     * If true, the list will be displayed in horizontal scrolling mode
     */
    horizontal?: boolean;
    /**
     * Check if phone is in landscape mode.
     * This will apply the landscape mode styles to the component.
     */
    landscape?: boolean;
};
/**
 * This component displays a list of participants in a FlatList.
 * You can use this component to display participants either in a vertical or horizontal scrolling mode.
 * NOTE: this component depends on a flex container to calculate the width and height of the participant view,
 * hence it should be used only in a flex parent container
 */
export declare const CallParticipantsList: ({ numberOfColumns, horizontal, participants, ParticipantView, ParticipantLabel, ParticipantNetworkQualityIndicator, ParticipantReaction, ParticipantVideoFallback, VideoRenderer, supportedReactions, landscape, }: CallParticipantsListProps) => React.JSX.Element;
//# sourceMappingURL=CallParticipantsList.d.ts.map