import React from 'react';
import { type HostLivestreamTopViewProps } from '../LivestreamTopView/HostLivestreamTopView';
import { type HostLivestreamControlsProps } from '../LivestreamControls/HostLivestreamControls';
import { type LivestreamLayoutProps } from '../LivestreamLayout';
import { type FloatingParticipantViewProps } from '../../Participant/FloatingParticipantView';
import { type ScreenShareOverlayProps } from '../../utility/ScreenShareOverlay';
/**
 * Props for the HostLivestream component.
 */
export type HostLivestreamProps = Omit<HostLivestreamTopViewProps, 'onLayout'> & Omit<HostLivestreamControlsProps, 'onLayout'> & {
    /**
     * Component to customize the top view at the host's live stream.
     */
    HostLivestreamTopView?: React.ComponentType<HostLivestreamTopViewProps> | null;
    /**
     * Component to customize the live stream video layout.
     */
    LivestreamLayout?: React.ComponentType<LivestreamLayoutProps> | null;
    /**
     * Component to customize the bottom view controls at the host's live stream.
     */
    HostLivestreamControls?: React.ComponentType<HostLivestreamControlsProps> | null;
    /**
     * Component to customize the FloatingParticipantView when screen is shared.
     */
    FloatingParticipantView?: React.ComponentType<FloatingParticipantViewProps> | null;
    /**
     * Component to customize the ScreenShareOverlay.
     */
    ScreenShareOverlay?: React.ComponentType<ScreenShareOverlayProps> | null;
};
/**
 * The HostLivestream component displays the UI for the Host's live stream.
 */
export declare const HostLivestream: ({ HostLivestreamTopView, HostLivestreamControls, LivestreamLayout, FloatingParticipantView, ScreenShareOverlay, LiveIndicator, FollowerCount, DurationBadge, HostStartStreamButton, LivestreamMediaControls, onEndStreamHandler, onStartStreamHandler, hls, disableStopPublishedStreamsOnEndStream, }: HostLivestreamProps) => React.JSX.Element;
//# sourceMappingURL=HostLivestream.d.ts.map