import React from 'react';
import { type ViewerLivestreamTopViewProps } from '../LivestreamTopView/ViewerLivestreamTopView';
import { type ViewerLivestreamControlsProps } from '../LivestreamControls/ViewerLivestreamControls';
import type { ViewerLeaveStreamButtonProps } from '../LivestreamControls/ViewerLeaveStreamButton';
import { type LivestreamLayoutProps } from '../LivestreamLayout';
import { type FloatingParticipantViewProps } from '../../Participant';
/**
 * Props for the ViewerLivestream component.
 */
export type ViewerLivestreamProps = ViewerLivestreamTopViewProps & ViewerLivestreamControlsProps & ViewerLeaveStreamButtonProps & {
    /**
     * Component to customize the top view at the viewer's live stream.
     */
    ViewerLivestreamTopView?: React.ComponentType<ViewerLivestreamTopViewProps> | null;
    /**
     * Component to customize the live stream video layout.
     */
    LivestreamLayout?: React.ComponentType<LivestreamLayoutProps> | null;
    /**
     * Component to customize the bottom view controls at the viewer's live stream.
     */
    ViewerLivestreamControls?: React.ComponentType<ViewerLivestreamControlsProps> | null;
    /**
     * Component to customize the FloatingParticipantView when screen is shared.
     */
    FloatingParticipantView?: React.ComponentType<FloatingParticipantViewProps> | null;
    /**
     * Determines when the viewer joins the call.
     *
     * `"asap"` behavior means joining the call as soon as it is possible
     * (either the `join_ahead_time_seconds` setting allows it, or the user
     * has a the capability to join backstage).
     */
    joinBehavior?: 'asap' | 'live';
};
/**
 * The ViewerLivestream component renders the UI for the Viewer's live stream.
 */
export declare const ViewerLivestream: ({ ViewerLivestreamTopView, ViewerLivestreamControls, LivestreamLayout, FloatingParticipantView, LiveIndicator, FollowerCount, DurationBadge, ViewerLeaveStreamButton, onLeaveStreamHandler, joinBehavior, }: ViewerLivestreamProps) => React.JSX.Element;
//# sourceMappingURL=ViewerLivestream.d.ts.map