import React from 'react';
import type { StreamVideoParticipant } from '@stream-io/video-client';
import { type Theme } from '../../theme/theme';
/**
 * Props to be passed for the Avatar component.
 */
export interface AvatarProps {
    /**
     * The participant of which the avatar will be rendered
     */
    participant: StreamVideoParticipant;
    /**
     * The size of the avatar
     * @defaultValue
     * The default value is `100`
     */
    size?: number;
    /**
     * Custom style to be merged with the avatar.
     * @example
     * ```
     * <Avatar
     *  participant={participant}
     *  style={{
     *   container: {
     *    backgroundColor: 'red',
     *   },
     *   image: {
     *    borderRadius: 10,
     *   },
     *   text: {
     *     color: 'white',
     *   },
     *   }}
     * />
     */
    style?: Theme['avatar'];
}
/**
 * Shows either user's image or initials based on the user state and existence of
 * their image.
 */
export declare const Avatar: (props: AvatarProps) => React.JSX.Element;
//# sourceMappingURL=Avatar.d.ts.map