import React, { type PropsWithChildren } from 'react';
import { Image } from 'react-native';
declare const resolveAssetSourceFunc: typeof Image.resolveAssetSource;
type ImageSourceType = Exclude<Parameters<typeof resolveAssetSourceFunc>[0], Array<any>>;
export type BlurIntensity = 'light' | 'medium' | 'heavy';
export type BackgroundFilterType = 'blur' | 'image';
export type CurrentBackgroundFilter = {
    blur?: BlurIntensity;
    image?: ImageSourceType;
};
export type BackgroundFiltersAPI = {
    /**
     * The currently applied background filter. Undefined value indicates that no filter is applied.
     */
    currentBackgroundFilter: CurrentBackgroundFilter | undefined;
    /**
     * Whether the current device supports the background filters.
     */
    isSupported: boolean;
    /**
     * Applies a background image filter to the video.
     *
     * @param imageSource the URL of the image to use as the background.
     */
    applyBackgroundImageFilter: (imageSource: ImageSourceType) => void;
    /**
     * Applies a background blur filter to the video.
     *
     * @param blurLevel the level of blur to apply to the background.
     */
    applyBackgroundBlurFilter: (blurIntensity: BlurIntensity) => void;
    /**
     * Disables all filters applied to the video.
     */
    disableAllFilters: () => void;
};
/**
 * A hook to access the background filters context API.
 */
export declare const useBackgroundFilters: () => BackgroundFiltersAPI;
/**
 * A provider component that enables the use of background filters in your app.
 *
 * Please make sure you have the `@stream-io/video-filters-react-native` package installed
 * in your project before using this component.
 */
export declare const BackgroundFiltersProvider: ({ children }: PropsWithChildren) => React.JSX.Element;
export {};
//# sourceMappingURL=BackgroundFilters.d.ts.map