import { StreamVideoParticipant, type VideoTrackType } from '@stream-io/video-client';
/**
 * Hook that provides functionality to take screenshots of participant video streams.
 *
 * @returns An object containing the `takeScreenShot` function that captures a participant's video.
 */
type UseScreenshotResult = {
    /**
     * Takes a screenshot of a participant's video stream.
     *
     * @param participant - The participant whose video stream to capture
     * @param videoTrackType - The type of video track to capture ('videoTrack' or 'screenShareTrack')
     * @returns A Promise that resolves to a base64-encoded png image string or null if the screenshot fails
     */
    takeScreenshot: (participant: StreamVideoParticipant, videoTrackType: VideoTrackType) => Promise<string | null>;
};
export declare function useScreenshot(): UseScreenshotResult;
export {};
//# sourceMappingURL=useScreenshot.d.ts.map