import React, { PropsWithChildren } from 'react';
/**
 * The Noise Cancellation API.
 */
export type NoiseCancellationAPI = {
    /**
     * A boolean providing information whether the device supports advanced audio processing recommended for noise cancellation.
     * This boolean returns `true` if the iOS device supports Apple's Neural Engine or if an Android device has the FEATURE_AUDIO_PROCESSING feature enabled.
     * Devices with this capability are better suited for handling noise cancellation efficiently.
     */
    deviceSupportsAdvancedAudioProcessing: boolean | undefined;
    /**
     * A boolean providing information whether Noise Cancelling functionalities
     * are supported for the current user in call settings.
     */
    isSupported: boolean | undefined;
    /**
     * Provides information whether Noise Cancellation is active or not.
     */
    isEnabled: boolean;
    /**
     * Allows you to enable or disable the Noise Cancellation audio filter.
     *
     * @param enabled a boolean or a setter.
     */
    setEnabled: (enabled: boolean | ((value: boolean) => boolean)) => void;
};
/**
 * Exposes the NoiseCancellation API.
 * Throws an error if used outside <NoiseCancellationProvider />.
 */
export declare const useNoiseCancellation: () => NoiseCancellationAPI;
export declare const NoiseCancellationProvider: (props: PropsWithChildren<{}>) => React.JSX.Element;
//# sourceMappingURL=NoiseCancellationProvider.d.ts.map