import { type ImageStyle, type TextStyle, type ViewStyle } from 'react-native/types';
import { type ColorScheme, type DimensionType, type FontStyle, type FontTypes, type Insets } from './types';
import { type ColorValue } from 'react-native';
export type Theme = {
    variants: {
        buttonSizes: DimensionType;
        roundButtonSizes: DimensionType;
        iconSizes: DimensionType;
        avatarSizes: DimensionType;
        fontSizes: DimensionType;
        spacingSizes: DimensionType;
        borderRadiusSizes: DimensionType;
        insets: Insets;
    };
    typefaces: Record<FontTypes, FontStyle>;
    defaults: {
        color: ColorValue;
        backgroundColor: ColorValue;
        margin: number;
        padding: number;
        fontSize: number;
        iconSize: number;
        fontWeight: TextStyle['fontWeight'];
        borderRadius: ViewStyle['borderRadius'];
        borderColor: ColorValue;
        borderWidth: ViewStyle['borderWidth'];
    };
    colors: ColorScheme;
    avatar: {
        container: ViewStyle;
        image: ImageStyle;
        text: TextStyle;
    };
    callContent: {
        container: ViewStyle;
        callParticipantsContainer: ViewStyle;
        topContainer: ViewStyle;
    };
    callControls: {
        container: ViewStyle;
    };
    callControlsButton: {
        container: ViewStyle;
        svgContainer: ViewStyle;
    };
    acceptCallButton: {
        container: ViewStyle;
        svgContainer: ViewStyle;
    };
    hangupCallButton: {
        container: ViewStyle;
        svgContainer: ViewStyle;
    };
    rejectCallButton: {
        container: ViewStyle;
        svgContainer: ViewStyle;
    };
    screenShareToggleButton: {
        container: ViewStyle;
        svgContainer: ViewStyle;
    };
    toggleAudioPreviewButton: {
        container: ViewStyle;
        svgContainer: ViewStyle;
    };
    toggleAudioPublishingButton: {
        container: ViewStyle;
        svgContainer: ViewStyle;
    };
    toggleCameraFaceButton: {
        container: ViewStyle;
        svgContainer: ViewStyle;
    };
    toggleVideoPreviewButton: {
        container: ViewStyle;
        svgContainer: ViewStyle;
    };
    toggleVideoPublishingButton: {
        container: ViewStyle;
        svgContainer: ViewStyle;
    };
    joinCallButton: {
        container: ViewStyle;
        label: TextStyle;
    };
    floatingParticipantsView: {
        container: ViewStyle;
        participantViewContainer: ViewStyle;
        videoFallback: ViewStyle;
    };
    chatButton: {
        container: ViewStyle;
        svgContainer: ViewStyle;
    };
    callParticipantsGrid: {
        container: ViewStyle;
    };
    callParticipantsSpotlight: {
        container: ViewStyle;
        fullScreenSpotlightContainer: ViewStyle;
        callParticipantsListContainer: ViewStyle;
        spotlightContainer: ViewStyle;
    };
    lobby: {
        container: ViewStyle;
        topContainer: ViewStyle;
        heading: TextStyle;
        subHeading: TextStyle;
        videoContainer: ViewStyle;
        bottomContainer: ViewStyle;
        infoContainer: ViewStyle;
        infoText: TextStyle;
        participantStatusContainer: ViewStyle;
        avatarContainer: ViewStyle;
        userNameLabel: TextStyle;
        audioMutedIconContainer: ViewStyle;
    };
    participantLabel: {
        container: ViewStyle;
        userNameLabel: TextStyle;
        audioMutedIconContainer: ViewStyle;
        videoMutedIconContainer: ViewStyle;
        pinIconContainer: ViewStyle;
        screenShareIconContainer: ViewStyle;
    };
    participantNetworkQualityIndicator: {
        container: ViewStyle;
    };
    participantReaction: {
        container: ViewStyle;
        reaction: ViewStyle;
    };
    participantVideoFallback: {
        container: ViewStyle;
        label: TextStyle;
        avatarContainer: ViewStyle;
        avatarText: TextStyle;
        avatarImage: ImageStyle;
    };
    participantView: {
        container: ViewStyle;
        footerContainer: ViewStyle;
        highlightedContainer: ViewStyle;
    };
    videoRenderer: {
        container: ViewStyle;
        videoStream: ViewStyle;
    };
    ringingCallContent: {
        container: ViewStyle;
    };
    incomingCall: {
        background: ViewStyle;
        content: ViewStyle;
        topContainer: ViewStyle;
        incomingCallText: TextStyle;
        incomingCallControls: ViewStyle;
        bottomContainer: ViewStyle;
        buttonGroup: ViewStyle;
    };
    outgoingCall: {
        container: ViewStyle;
        background: ViewStyle;
        content: ViewStyle;
        topContainer: ViewStyle;
        callingText: TextStyle;
        outgoingCallControls: ViewStyle;
        bottomContainer: ViewStyle;
        buttonGroup: ViewStyle;
        deviceControlButtons: ViewStyle;
    };
    userInfo: {
        container: ViewStyle;
        avatarGroup: ViewStyle;
        name: TextStyle;
    };
    reactionsPicker: {
        reactionsPopup: ViewStyle;
        reactionsButtonDimmer: ViewStyle;
        reactionItem: ViewStyle;
        reactionText: TextStyle;
    };
    lobbyControls: {
        container: ViewStyle;
    };
    participantInfoBadge: {
        container: ViewStyle;
        participantCountContainer: ViewStyle;
        participantsIconContainer: ViewStyle;
        participantsCountText: TextStyle;
    };
    hostLivestream: {
        container: ViewStyle;
    };
    viewerLivestream: {
        container: ViewStyle;
    };
    livestreamLayout: {
        container: ViewStyle;
    };
    hostLivestreamTopView: {
        container: ViewStyle;
        leftElement: ViewStyle;
        centerElement: ViewStyle;
        rightElement: ViewStyle;
        liveInfo: ViewStyle;
    };
    viewerLivestreamTopView: {
        container: ViewStyle;
        leftElement: ViewStyle;
        centerElement: ViewStyle;
        rightElement: ViewStyle;
        liveInfo: ViewStyle;
    };
    followerCount: {
        container: ViewStyle;
        icon: ViewStyle;
        label: TextStyle;
    };
    durationBadge: {
        container: ViewStyle;
        icon: ViewStyle;
        label: TextStyle;
    };
    liveIndicator: {
        container: ViewStyle;
        label: TextStyle;
    };
    hostLivestreamControls: {
        container: ViewStyle;
        leftElement: ViewStyle;
        rightElement: ViewStyle;
    };
    viewerLivestreamControls: {
        container: ViewStyle;
        leftElement: ViewStyle;
        rightElement: ViewStyle;
    };
    hostStartStreamButton: {
        container: ViewStyle;
        icon: ViewStyle;
        text: TextStyle;
    };
    viewerLeaveStreamButton: {
        container: ViewStyle;
        icon: ViewStyle;
        text: TextStyle;
    };
    livestreamMediaControls: {
        container: ViewStyle;
    };
    livestreamAudioControlButton: {
        container: ViewStyle;
        icon: ViewStyle;
    };
    livestreamVideoControlButton: {
        container: ViewStyle;
        icon: ViewStyle;
    };
    livestreamScreenShareToggleButton: {
        container: ViewStyle;
        icon: ViewStyle;
    };
    screenshareOverlay: {
        container: ViewStyle;
        text: TextStyle;
        button: ViewStyle;
        buttonIcon: ViewStyle;
        buttonText: TextStyle;
    };
    [component: string]: any;
};
export declare const defaultTheme: Theme;
//# sourceMappingURL=theme.d.ts.map